@@ -444,7 +444,6 @@ static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 			className(parm, (parseUnion*)&lvalp.xtokClassName);
 			op = newCMPIObjectPath(NULL, lvalp.xtokClassName.value, NULL);
 			simpleArrayAdd(parm->respHdr.rvArray,(CMPIValue*)&op,CMPI_ref);
-			if(op) op->ft->release(op);
 			ct = localLex(&lvalp, parm);
 		}
 		while(ct == XTOK_CLASSNAME);
@@ -468,7 +467,6 @@ static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 			instanceName(parm, (parseUnion*)&lvalp.xtokInstanceName);
 			createPath(&op, &lvalp.xtokInstanceName);
 			simpleArrayAdd(parm->respHdr.rvArray,(CMPIValue*)&op,CMPI_ref);
-			if(op) op->ft->release(op);
 			ct = localLex(&lvalp, parm);
 		}
 		while(ct == XTOK_INSTANCENAME);
@@ -481,10 +479,10 @@ static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 			createPath(&op,&(lvalp.xtokNamedInstance.path));
 			CMSetNameSpace(op, getNameSpaceChars(parm->requestObjectPath));
 			inst = native_new_CMPIInstance(op,NULL);
+			op->ft->release(op);
 			//setInstQualifiers(inst, &lvalp.xtokNamedInstance.instance.qualifiers);
 			setInstProperties(inst, &lvalp.xtokNamedInstance.instance.properties);
 			simpleArrayAdd(parm->respHdr.rvArray,(CMPIValue*)&inst,CMPI_instance);
-			if(op) op->ft->release(op);
 			ct = localLex(&lvalp, parm);
 		}
 		while(ct == XTOK_VALUENAMEDINSTANCE);
@@ -498,7 +496,6 @@ static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 			CMSetNameSpace(op, lvalp.xtokObjectPath.path.path.nameSpacePath.value);
 			CMSetHostname(op, lvalp.xtokObjectPath.path.path.host.host);
 			simpleArrayAdd(parm->respHdr.rvArray,(CMPIValue*)&op,CMPI_ref);
-			if(op) op->ft->release(op);
 			ct = localLex(&lvalp, parm);
 		}
 		while(ct == XTOK_OBJECTPATH);
